/* ANDREWS.G

This file calculates tests for structural change, from
Bruce Hansen, "Testing for Structural Change in Conditional Models",
Journal of Econometrics (2000),

Original code was downloaded from Bruce Hansen's web page,
http://www.ssc.wisc.edu/~bhansen/progs/joe_00.html

The program fits the first equation from a bi-variate VAR(4) 
in quarterly GDP growth and measure of oil prices, and tests for parameter
instability in the VAR parameters.

The output is written to the file "junk".

Original program was written by

Bruce E. Hansen
Department of Economics
Social Science Building
University of Wisconsin
Madison, WI 53706-1393
bhansen@ssc.wisc.edu
http://www.ssc.wisc.edu/~bhansen/

The file calls the procedure break_t contained in the ASCII file
break.prc, which calls procedures contained in the ASCII files
pv_sup.prc, pv_exp.prc and pv_ave.prc


*/

#include break.prc;   @ loads procs for testing for structural breaks @
#include ..\data2001\reoil01.g;   @ reads in data @

format 9,4;
output file = junk reset;

lag = 4;
"Autoregressive Lag Order= " lag;


x = xlin;
oilmeas = 1;
do until oilmeas > 5;
if oilmeas == 1;
	"oil price measure = change in nominal oil price";
	x = xlin;
elseif oilmeas == 2;
	xlin = ones(rows(xlin),1) ~ xlin[.,lag+1:2*lag];      @ converts xlin to constant and lagged
											 gdp growth @
	x = xlin ~ xzham;
	"oil price measure = Hamilton net oil";
elseif oilmeas == 3;
	"oil price measure = Mork";
	x = xlin ~ xzmork;
elseif oilmeas == 4;
	"oil price measure = Lee";
	x = xlin ~ xlee1;
elseif oilmeas == 5;
	"oil price measure = Hamilton 3-year net oil";
	x = xlin ~ x3ham;
endif;

pi1=.15;
pi2=.85;

qvar = "GDP";
 qvar = qvar $| "Constant"; 

  qvar = qvar $| "GDP(-1)" $| "GDP(-2)" $| "GDP(-3)" $| "GDP(-4)";
   qvar = qvar $| "oil(-1)" $| "oil(-2)" $| "oil(-3)" $| "oil(-4)"; 


  break_t(y,x,qvar,pi1,pi2);
  "";"";
oilmeas = oilmeas +1;
endo;
output off;

